@@ -1,6 +1,6 @@
 package Zonemaster::WebBackend::DB;
 
-our $VERSION = '1.0.7';
+our $VERSION = '1.1.0';
 
 use Moose::Role;
 
@@ -9,7 +9,7 @@ use 5.14.2;
 use Data::Dumper;
 
 requires 'add_api_user_to_db', 'user_exists_in_db', 'user_authorized', 'test_progress', 'test_results',
-  'create_new_batch_job', 'create_new_test', 'get_test_params', 'get_test_history';
+  'create_new_batch_job', 'create_new_test', 'get_test_params', 'get_test_history', 'add_batch_job';
 
 sub user_exists {
     my ( $self, $user ) = @_;
@@ -57,8 +57,16 @@ sub get_test_request {
 
     my $result_id;
     my $dbh = $self->dbh;
-    my ( $id, $hash_id ) = $dbh->selectrow_array(
-        q[ SELECT id, hash_id FROM test_results WHERE progress=0 ORDER BY priority ASC, id ASC LIMIT 1 ] );
+    
+    
+    my ( $id, $hash_id );
+    my $lock_on_queue = Zonemaster::WebBackend::Config->lock_on_queue();
+	if ( defined $lock_on_queue ) {
+		( $id, $hash_id ) = $dbh->selectrow_array( qq[ SELECT id, hash_id FROM test_results WHERE progress=0 AND queue=? ORDER BY priority DESC, id ASC LIMIT 1 ], undef, $lock_on_queue );
+	}
+	else {
+		( $id, $hash_id ) = $dbh->selectrow_array( q[ SELECT id, hash_id FROM test_results WHERE progress=0 ORDER BY priority DESC, id ASC LIMIT 1 ] );
+	}
         
     if ($id) {
 		$dbh->do( q[UPDATE test_results SET progress=1 WHERE id=?], undef, $id );
